@@ -1,3 +1,9 @@
+# For backwards compatibility, we import JSONField to have it available for import via
+# this compat module (https://github.com/graphql-python/graphene-django/issues/1428).
+# Django's JSONField is available in Django 3.2+ (the minimum version we support)
+from django.db.models import JSONField
+
+
 class MissingType:
     def __init__(self, *args, **kwargs):
         pass
@@ -10,16 +16,7 @@ try:
         IntegerRangeField,
         ArrayField,
         HStoreField,
-        JSONField as PGJSONField,
         RangeField,
     )
 except ImportError:
-    IntegerRangeField, ArrayField, HStoreField, PGJSONField, RangeField = (
-        MissingType,
-    ) * 5
-
-try:
-    # JSONField is only available from Django 3.1
-    from django.db.models import JSONField
-except ImportError:
-    JSONField = MissingType
+    IntegerRangeField, ArrayField, HStoreField, RangeField = (MissingType,) * 4
